# If there are this code in orther local have to use 
# from lazyearth.mainfile import objearth
# from lazyearth.mainfile import water

from lazyearth.mainfile import objearth
from lazyearth.mainfile import water

